import json

from mamba.formatters import Formatter


class JSONFormatter(Formatter):

    def __init__(self, settings):
        self.settings = settings
        self.results = []

    def example_started(self, example):
        pass

    def example_passed(self, example):
        self._dump_example(example)

    def example_failed(self, example):
        self._dump_example(example, 'failed')

    def example_pending(self, example):
        self._dump_example(example, 'pending')

    def example_group_started(self, example_group):
        pass

    def example_group_finished(self, example_group):
        pass

    def example_group_pending(self, example_group):
        pass

    def summary(self, duration, example_count, failed_count, pending_count):
        print(json.dumps({'results': self.results}))

    def failures(self, failed_examples):
        pass

    def _dump_example(self, example, status=None):
        self.results.append({
            'name': example.name,
            'status': status or 'passed',
            'file_path': example.file,
        })



from setuptools import setup


setup(
    name='mamba-json-formatter',
    version='0.0.1',
    license='MIT/X11',
    author='Quique Porta',
    author_email='quiqueporta@gmail.com',
    description='JSON formatter for mamba',
    long_description=open('README.md').read(),
    url='https://github.com/quiqueporta/mamba-json-formatter',
    download_url='https://github.com/quiqueporta/mamba-json-formatter/releases',
    keywords=['python', 'testing'],
    packages=['mamba_json_formatter'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities',
    ],
    install_requires=['mamba'],
)